@@ -10,7 +10,7 @@
 
 enum {
 	PLATFORM_UNKNOWN = 0,
-	PLATFORM_POWERKVM,
+	PLATFORM_POWERNV,
 	PLATFORM_POWERKVM_GUEST,
 	PLATFORM_PSERIES_LPAR,
 	/* Add new platforms here */
