@@ -27,6 +27,7 @@
 #define _GNU_SOURCE
 #include <getopt.h>
 #include <sys/stat.h>
+#include <inttypes.h>
 #include <servicelog-1/servicelog.h>
 #include "config.h"
 #include "platform.h"
@@ -176,7 +177,7 @@ main(int argc, char *argv[])
 	 * All this needs to be revisited.
 	 */
 	char type_match[1024], *type_tmp = NULL;
-	char *next = type_match;
+	char *next = type_match, *end = next + sizeof(type_match) - 1;
 	int notify_flag = 0;
 	uint64_t id=0;
 	char *command=NULL, *match=NULL, query[256], cmdbuf[256];
@@ -194,7 +195,7 @@ main(int argc, char *argv[])
 	platform = get_platform();
 	switch (platform) {
 	case PLATFORM_UNKNOWN:
-	case PLATFORM_POWERKVM:
+	case PLATFORM_POWERNV:
 		fprintf(stderr, "%s: is not supported on the %s platform\n",
 					cmd, __power_platform_name(platform));
 		exit(1);
@@ -408,16 +409,19 @@ main(int argc, char *argv[])
 	/* Added for v0.2.9 backwards compatibility */
 	// Build a match string out of the provided params
 	if (tSev) {
-		next += sprintf(next,"%s severity>=%s", connector, tSev);
+		next += snprintf(next, (end - next),
+			"%s severity>=%s", connector, tSev);
 		connector = " and ";
 	}
 
 	if (servicable) {
 		if (servicable == SL_QUERY_NO) {
-			next += sprintf(next,"%s serviceable=0", connector);
+			next += snprintf(next, (end - next),
+			"%s serviceable=0", connector);
 			connector = " and ";
 		} else if (servicable == SL_QUERY_YES) {
-			next += sprintf(next,"%s serviceable=1", connector);
+			next += snprintf(next, (end - next),
+			"%s serviceable=1", connector);
 			connector = " and ";
 		}
 	}
@@ -454,8 +458,13 @@ main(int argc, char *argv[])
 			/* Must register two events, since in v1 EVENT and REPAIR cannot be done with 1 DB entry */
 			/* set up an sl_notify struct and call servicelog_notify_log */
 			if (notify_flag & TYPE_EVENTS) {
-				notify = (struct sl_notify *)malloc(sizeof(struct sl_notify));
-				memset(notify, 0, sizeof(struct sl_notify));
+				notify = calloc(1, sizeof(struct sl_notify));
+				if (!notify) {
+					fprintf(stderr, "malloc failed, while"
+					" allocating notify.\n\n");
+					rc = 1;
+					goto err_out;
+				} /* calloc */
 				notify->notify = SL_NOTIFY_EVENTS;
 				notify->method = method;
 
@@ -474,7 +483,7 @@ main(int argc, char *argv[])
 				rc = servicelog_notify_log(servlog, notify, &id);
 				servicelog_notify_free(notify);
 				if (rc == 0) {
-					printf("Event Notification Registration successful (id: %llu)\n", id);
+					printf("Event Notification Registration successful (id: ""%" PRIu64 ")\n", id);
 				}
 				else {
 					fprintf(stderr, "%s\n", servicelog_error(servlog));
@@ -485,12 +494,17 @@ main(int argc, char *argv[])
 
 			if (notify_flag & TYPE_REPAIRS) {
 				/* set up an sl_notify struct and call servicelog_notify_log */
-				notify = (struct sl_notify *)malloc(sizeof(struct sl_notify));
-				memset(notify, 0, sizeof(struct sl_notify));
+				notify = calloc(1, sizeof(struct sl_notify));
+				if (!notify) {
+					fprintf(stderr, "malloc failed, while"
+					" allocating notify.\n\n");
+					rc = 1;
+					goto err_out;
+				} /* calloc */
 				notify->notify = SL_NOTIFY_REPAIRS;
 				notify->method = method;
 
-				/* A v1 command line arg will take precidence */
+				/* A v1 command line arg will take precedence */
 				if (match)
 					notify->match = strdup(match);
 				else
@@ -509,7 +523,7 @@ main(int argc, char *argv[])
 				rc = servicelog_notify_log(servlog, notify, &id);
 				servicelog_notify_free(notify);
 				if (rc == 0) {
-					printf("Repair Notification Registration successful (id: %llu)\n", id);
+					printf("Repair Notification Registration successful (id: ""%" PRIu64 ")\n", id);
 				}
 				else {
 					fprintf(stderr, "%s\n", servicelog_error(servlog));
@@ -549,7 +563,7 @@ main(int argc, char *argv[])
 				} else if (notify == NULL) {
 					fprintf(stderr, "Could not find a registered "
 						"notification tool with the specified "
-						"id (%llu).\n", id);
+						"id (""%" PRIu64 ").\n", id);
 					rc = 1;
 					goto err_out;
 				}
@@ -585,7 +599,7 @@ main(int argc, char *argv[])
 				}
 			}
 
-			/* diplay the notification tools */
+			/* display the notification tools */
 			servicelog_notify_print(stdout, notify, 2);
 			servicelog_notify_free(notify);
 		break;
@@ -611,7 +625,7 @@ main(int argc, char *argv[])
 			} else if (notify == NULL) {
 				fprintf(stderr, "Could not find a registered "
 					"notification tool with the specified "
-					"id (%llu).\n", id);
+					"id (""%" PRIu64 ").\n", id);
 				rc = 1;
 				goto err_out;
 			}
